### MMGen Version 13.0.2 Release Notes

This micro-release adds a couple of tweaks to the build/install system for
compatibility with the latest version of MSYS2.  Windows users should upgrade,
after first upgrading MSYS2, if necessary.  Note that the MMGen install process
has changed.  For details, refer to [Keeping your installation up to date][ms]
on the Windows install wiki page.

#### Changes from v13.0.1:

 - `setup.cfg`: remove an unneeded dependency
 - `setup.py`: update libsecp256k1 `make` command

[ms]: https://github.com/mmgen/mmgen/wiki/Install-MMGen-on-Microsoft-Windows#a_u
